# AUTOGENERATED! DO NOT EDIT! File to edit: nbs/jupyter_notebook.ipynb (unless otherwise specified).

__all__ = ['is_in_notebook']

# Cell

import importlib
import os, sys

def is_in_notebook():
    try:
        # Test adapted from tqdm.autonotebook: https://github.com/tqdm/tqdm/blob/master/tqdm/autonotebook.py
        get_ipython = sys.modules["IPython"].get_ipython
        if "IPKernelApp" not in get_ipython().config:
            raise ImportError("console")

        return importlib.util.find_spec("IPython") is not None
    except (AttributeError, ImportError, KeyError):
        return False


# AUTOGENERATED! DO NOT EDIT! File to edit: nbs/load_defautls.ipynb (unless otherwise specified).

__all__ = ['ifexists', 'ifnone']

# Cell

from .loader import os
from .paths import loaddill

from fastcore.basics import ifnone

ifnone = ifnone

def ifexists(fpath, default):
    if os.path.exists(fpath):
        return loaddill(fpath)
    else:
        return default


# AUTOGENERATED! DO NOT EDIT! File to edit: nbs/charts.ipynb (unless otherwise specified).

__all__ = ['alt', 'Chart', 'confusion_matrix', 'CM']

# Cell
# export
import altair as alt
from altair import Chart

alt = alt
Chart = Chart
from .loader import *

# Cell
def confusion_matrix(df=None, truth=None, pred=None, mapping=None):
    if df is None:
        df = pd.DataFrame({"truth": truth, "pred": pred})
        truth = "truth"
        pred = "pred"
    threshold = len(df)
    if mapping:
        assert isinstance(mapping, dict), "mapping should be a dictionary"
        df[truth] = df[truth].map(lambda x: mapping[x])
        df[pred] = df[pred].map(lambda x: mapping[x])

    sz = 450 if len(df[truth].unique()) > 4 else 250
    base = (
        Chart(df, height=sz, width=sz)
        .transform_aggregate(num_vals="count()", groupby=[truth, pred])
        .transform_calculate(
            rev_num_vals="-(datum.num_vals) + max(datum.num_vals)",
        )
        .encode(
            alt.Y(f"{truth}:O", scale=alt.Scale(paddingInner=0)),
            alt.X(f"{pred}:O", scale=alt.Scale(paddingInner=0)),
        )
    )

    hm = base.mark_rect().encode(
        color=alt.Color(
            "num_vals:Q", scale=alt.Scale(scheme="lightorange"), legend=None
        )
    )

    tx = base.mark_text(baseline="middle").encode(
        text="num_vals:Q",
        #         color=alt.Color(alt.value('gray'))
        #         color='rev_num_vals:Q'
        #         color=alt.Color(
        #             'num_vals:Q', scale=alt.Scale(scheme="redyellowgreen"),
        #         )
        color=alt.condition(
            alt.datum.num_vals > threshold, alt.value("black"), alt.value("black")
        ),
    )

    try:
        from sklearn.metrics import classification_report

        print(classification_report(df[truth], df[pred]))
    except:
        logger.info("Skipping Report")
    return hm + tx


CM = confusion_matrix


# AUTOGENERATED! DO NOT EDIT! File to edit: nbs/adapters.ipynb (unless otherwise specified).

__all__ = ['np_2_b64', 'b64_2_np', 'b64_2_pdf']

# Cell
import base64, cv2, numpy as np


def np_2_b64(image):
    img_str = cv2.imencode(".jpg", image)[1].tobytes()
    img_b64 = base64.b64encode(img_str).decode("utf-8")
    return img_b64


def b64_2_np(input):
    input = bytes(input, "utf-8")
    input = base64.b64decode(input)
    img_nparr = np.frombuffer(input, np.uint8)
    img_cv2 = cv2.imdecode(img_nparr, cv2.IMREAD_COLOR)
    img_rgb = cv2.cvtColor(img_cv2, cv2.COLOR_BGR2RGB)
    return img_rgb


def b64_2_pdf(input, fpath):
    with open(fpath, "wb") as pdf_file:
        input = bytes(input, "utf-8")
        input = base64.b64decode(input)
        pdf_file.write(input)
        logger.info(f"wrote pdf file to {fpath}")



__version__ = "0.499.2"
from .loader import *
from .charts import *
from .paths import *
from .markup import *
from .inspector import *
from .load_defaults import *
from .pdf_loader import PDF

try:
    from .torch_loader import *
except Exception as e:
    ...

try:
    from .sklegos import *
except Exception as e:
    ...

try:
    from .imgaug_loader import *
except Exception as e:
    ...



# AUTOGENERATED! DO NOT EDIT! File to edit: nbs/bounding_boxes.ipynb (unless otherwise specified).

__all__ = ['iou', 'to_relative', 'to_absolute']

# Cell
import numpy as np
from .loader import *

def iou(bboxes1, bboxes2):
    bboxes1 = np.array(bboxes1)
    bboxes2 = np.array(bboxes2)
    x11, y11, x12, y12 = np.split(bboxes1, 4, axis=1)
    x21, y21, x22, y22 = np.split(bboxes2, 4, axis=1)
    xA = np.maximum(x11, np.transpose(x21))
    yA = np.maximum(y11, np.transpose(y21))
    xB = np.minimum(x12, np.transpose(x22))
    yB = np.minimum(y12, np.transpose(y22))
    interArea = np.maximum((xB - xA + 1), 0) * np.maximum((yB - yA + 1), 0)
    boxAArea = (x12 - x11 + 1) * (y12 - y11 + 1)
    boxBArea = (x22 - x21 + 1) * (y22 - y21 + 1)
    iou = interArea / (boxAArea + np.transpose(boxBArea) - interArea)
    return iou

# Cell

def to_relative(df, height, width):
    df = df.copy()
    df["x"] = df["x"] / width
    df["y"] = df["y"] / height
    df["X"] = df["X"] / width
    df["Y"] = df["Y"] / height
    return df

def to_absolute(df, height, width):
    df = df.copy()
    df["x"] = int(df["x"] * width)
    df["y"] = int(df["y"] * height)
    df["X"] = int(df["X"] * width)
    df["Y"] = int(df["Y"] * height)
    return df